@@ -2,7 +2,7 @@ package Test2::Event;
 use strict;
 use warnings;
 
-use Test2::Util::HashBase qw/trace nested/;
+use Test2::Util::HashBase qw/trace nested _meta/;
 
 sub causes_fail  { 0 }
 
@@ -10,6 +10,27 @@ sub update_state {()};
 sub terminate    {()};
 sub global       {()};
 
+sub set_meta {
+    my $self = shift;
+    my ($key, $value) = @_;
+
+    $self->{+META} ||= {};
+
+    $self->{+META}->{$key} = $value;
+}
+
+sub get_meta {
+    my $self = shift;
+    my ($key, $default) = @_;
+
+    $self->{+META} ||= {};
+
+    $self->{+META}->{$key} = $default
+        if defined($default) && !defined($self->{+META}->{$key});
+
+    return $self->{+META}->{$key};
+}
+
 1;
 
 __END__
@@ -111,6 +132,33 @@ to exit with a failure.
 This is called after the event has been sent to the formatter in order to
 ensure the event is seen and understood.
 
+=item $e->set_meta($key, $val)
+
+Some plugins may want to attach information to an event. This is a generic way
+to do that. C<$key> should be chosen likely, and is ideally prefixed with a
+package name to avoid conflicts.
+
+    $e->set_meta('Foo::Bar', { a => 1 });
+
+=item $e->get_meta($key)
+
+=item $e->get_meta($key, $default)
+
+This how you read meta data that is attached to an event. The key should match
+that used when the meta-data was set. Ideally keys are prefixed with package
+names to avoid conflicts.
+
+    # Get the value, or undef if there is none.
+    my $val = $e->get_meta('Foo::Bar');
+
+A default value can be specified as well. If there is no value attached to the
+event then the default will be attached and returned.
+
+    # Get the value, or set it to 'xxx' and get that.
+    my $val = $e->get_meta('Foo::Bar', 'xxx');
+
+=back
+
 =head1 SOURCE
 
 The source code repository for Test2 can be found at
